diff packages/net/lwip_tcpip/current/include/lwip/debug.h @ 2934:d6c0c0e0431c

* net/lwip_tcpip/current/*: Major update of lwIP TCP/IP stack to version 1.3.2. * io/eth/current/cdl/eth_drivers.cdl, include/eth_drv.h: Minor changes for lwIP 1.3.x. * io/eth/current/src/lwip/eth_drv.c: Rework for lwIP 1.3.x based on standalone driver for RedBoot. * io/eth/current/src/lwip/eth_conf.inl: Add static interface configuration.
author jld
date Tue, 26 Jan 2010 11:27:47 +0000
parents d07decb23fa2
children
line wrap: on
line diff
--- a/packages/net/lwip_tcpip/current/include/lwip/debug.h
+++ b/packages/net/lwip_tcpip/current/include/lwip/debug.h
@@ -32,56 +32,67 @@
 #ifndef __LWIP_DEBUG_H__
 #define __LWIP_DEBUG_H__
 
-#include "arch/cc.h"
+#include "lwip/arch.h"
 
 /** lower two bits indicate debug level
- * - 0 off
+ * - 0 all
  * - 1 warning
  * - 2 serious
  * - 3 severe
  */
-
-#define DBG_LEVEL_OFF     0
-#define DBG_LEVEL_WARNING 1  /* bad checksums, dropped packets, ... */
-#define DBG_LEVEL_SERIOUS 2  /* memory allocation failures, ... */
-#define DBG_LEVEL_SEVERE  3  /* */ 
-#define DBG_MASK_LEVEL    3
+#define LWIP_DBG_LEVEL_ALL     0x00
+#define LWIP_DBG_LEVEL_OFF     LWIP_DBG_LEVEL_ALL /* compatibility define only */
+#define LWIP_DBG_LEVEL_WARNING 0x01 /* bad checksums, dropped packets, ... */
+#define LWIP_DBG_LEVEL_SERIOUS 0x02 /* memory allocation failures, ... */
+#define LWIP_DBG_LEVEL_SEVERE  0x03
+#define LWIP_DBG_MASK_LEVEL    0x03
 
 /** flag for LWIP_DEBUGF to enable that debug message */
-#define DBG_ON  0x80U
+#define LWIP_DBG_ON            0x80U
 /** flag for LWIP_DEBUGF to disable that debug message */
-#define DBG_OFF 0x00U
+#define LWIP_DBG_OFF           0x00U
 
 /** flag for LWIP_DEBUGF indicating a tracing message (to follow program flow) */
-#define DBG_TRACE   0x40U
+#define LWIP_DBG_TRACE         0x40U
 /** flag for LWIP_DEBUGF indicating a state debug message (to follow module states) */
-#define DBG_STATE   0x20U
+#define LWIP_DBG_STATE         0x20U
 /** flag for LWIP_DEBUGF indicating newly added code, not thoroughly tested yet */
-#define DBG_FRESH   0x10U
+#define LWIP_DBG_FRESH         0x10U
 /** flag for LWIP_DEBUGF to halt after printing this debug message */
-#define DBG_HALT    0x08U
+#define LWIP_DBG_HALT          0x08U
 
 #ifndef LWIP_NOASSERT
-#  define LWIP_ASSERT(x,y) do { if(!(y)) LWIP_PLATFORM_ASSERT(x); } while(0)
-#else
-#  define LWIP_ASSERT(x,y) 
-#endif
+#define LWIP_ASSERT(message, assertion) do { if(!(assertion)) \
+  LWIP_PLATFORM_ASSERT(message); } while(0)
+#else  /* LWIP_NOASSERT */
+#define LWIP_ASSERT(message, assertion) 
+#endif /* LWIP_NOASSERT */
+
+/** if "expression" isn't true, then print "message" and execute "handler" expression */
+#ifndef LWIP_ERROR
+#define LWIP_ERROR(message, expression, handler) do { if (!(expression)) { \
+  LWIP_PLATFORM_ASSERT(message); handler;}} while(0)
+#endif /* LWIP_ERROR */
 
 #ifdef LWIP_DEBUG
 /** print debug message only if debug message type is enabled...
  *  AND is of correct type AND is at least DBG_LEVEL
  */
-#  define LWIP_DEBUGF(debug,x) do { if (((debug) & DBG_ON) && ((debug) & DBG_TYPES_ON) && ((s16_t)((debug) & DBG_MASK_LEVEL) >= DBG_MIN_LEVEL)) { LWIP_PLATFORM_DIAG(x); if ((debug) & DBG_HALT) while(1); } } while(0)
-#  define LWIP_ERROR(x)   do { LWIP_PLATFORM_DIAG(x); } while(0)  
-#else /* LWIP_DEBUG */
-#  define LWIP_DEBUGF(debug,x) 
-#  define LWIP_ERROR(x)  
+#define LWIP_DEBUGF(debug, message) do { \
+                               if ( \
+                                   ((debug) & LWIP_DBG_ON) && \
+                                   ((debug) & LWIP_DBG_TYPES_ON) && \
+                                   ((s16_t)((debug) & LWIP_DBG_MASK_LEVEL) >= LWIP_DBG_MIN_LEVEL)) { \
+                                 LWIP_PLATFORM_DIAG(message); \
+                                 if ((debug) & LWIP_DBG_HALT) { \
+                                   while(1); \
+                                 } \
+                               } \
+                             } while(0)
+
+#else  /* LWIP_DEBUG */
+#define LWIP_DEBUGF(debug, message) 
 #endif /* LWIP_DEBUG */
 
 #endif /* __LWIP_DEBUG_H__ */
 
-
-
-
-
-
@@ -32,56 +32,67 @@
 #ifdef LWIP_DEBUG
 /** print debug message only if debug message type is enabled...
- *  AND is of correct type AND is at least DBG_LEVEL
+ *  AND is of correct type AND is at least LWIP_DBG_LEVEL
  */